@@ -1,9 +1,9 @@
 package App::ModuleBuildTiny;
 
-use 5.008;
+use 5.010;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Exporter 5.57 'import';
 our @EXPORT = qw/modulebuildtiny/;
@@ -11,14 +11,12 @@ our @EXPORT = qw/modulebuildtiny/;
 use Carp qw/croak/;
 use Config;
 use CPAN::Meta;
-use ExtUtils::Manifest qw/manifind maniskip/;
+use ExtUtils::Manifest qw/manifind maniskip maniread/;
 use File::Basename qw/basename dirname/;
 use File::Copy qw/copy/;
 use File::Path qw/mkpath rmtree/;
 use File::Spec::Functions qw/catfile rel2abs/;
-use File::Temp qw/tempdir/;
 use Getopt::Long 2.39;
-use JSON::PP;
 
 sub write_file {
 	my ($filename, $content) = @_;
@@ -35,18 +33,24 @@ sub prereqs_for {
 
 sub get_files {
 	my %opts = @_;
-	my $maniskip = maniskip;
-	my $files = manifind();
-	delete $files->{$_} for @{ $opts{skip} }, grep { $maniskip->($_) } keys %$files;
+	my $files;
+	if (not $opts{regenerate}{MANIFEST} and -r 'MANIFEST') {
+		$files = maniread;
+	}
+	else {
+		my $maniskip = maniskip;
+		$files = manifind();
+		delete $files->{$_} for keys %{ $opts{regenerate} }, grep { $maniskip->($_) } keys %$files;
+	}
 	
-	$files->{'Build.PL'} ||= do {
+	$files->{'Build.PL'} //= do {
 		my $minimum_mbt  = prereqs_for($opts{meta}, qw/configure requires Module::Build::Tiny/);
 		my $minimum_perl = prereqs_for($opts{meta}, qw/runtime requires perl 5.006/);
-		\"use $minimum_perl;\nuse Module::Build::Tiny $minimum_mbt;\nBuild_PL();\n";
+		"use $minimum_perl;\nuse Module::Build::Tiny $minimum_mbt;\nBuild_PL();\n";
 	};
-	$files->{'META.json'} ||= \$opts{meta}->as_string;
-	$files->{'META.yml'} ||= \$opts{meta}->as_string({ version => 1.4 });
-	$files->{MANIFEST} ||= \join "\n", sort keys %$files;
+	$files->{'META.json'} //= $opts{meta}->as_string;
+	$files->{'META.yml'} //= $opts{meta}->as_string({ version => 1.4 });
+	$files->{MANIFEST} //= join "\n", sort keys %$files;
 
 	return $files;
 }
@@ -54,7 +58,7 @@ sub get_files {
 sub get_meta {
 	my %opts = @_;
 	my $mergefile = $opts{mergefile} || (grep { -f } qw/metamerge.json metamerge.yml/)[0];
-	if (not $opts{regenerate} and -e 'META.json' and -M 'META.json' < -M 'cpanfile' and (not $mergefile or -M 'META.json' < -M $mergefile)) {
+	if (not $opts{regenerate}{'META.json'} and -e 'META.json' and -M 'META.json' < -M 'cpanfile' and (not $mergefile or -M 'META.json' < -M $mergefile)) {
 		return CPAN::Meta->load_file('META.json', { lazy_validation => 0 });
 	}
 	else {
@@ -70,6 +74,7 @@ sub get_meta {
 
 		my $prereqs = -f 'cpanfile' ? do { require Module::CPANfile; Module::CPANfile->load('cpanfile')->prereq_specs } : {};
 		$prereqs->{configure}{requires}{'Module::Build::Tiny'} ||= Module::Metadata->new_from_module('Module::Build::Tiny')->version->stringify;
+		$prereqs->{develop}{requires}{'App::ModuleBuildTiny'} ||= $VERSION;
 
 		my $metahash = {
 			name           => $distname,
@@ -87,6 +92,7 @@ sub get_meta {
 			},
 		};
 		if ($mergefile && -r $mergefile) {
+			require Parse::CPAN::Meta;
 			my $extra = Parse::CPAN::Meta->load_file($mergefile);
 			require CPAN::Meta::Merge;
 			$metahash = CPAN::Meta::Merge->new(default_version => '2')->merge($metahash, $extra);
@@ -107,8 +113,8 @@ my %actions = (
 		my $name    = $meta->name . '-' . $meta->version;
 		my $content = get_files(%opts, meta => $meta);
 		for my $filename (keys %{$content}) {
-			if (ref $content->{$filename}) {
-				$arch->add_data($filename, ${ $content->{$filename} });
+			if ($content->{$filename}) {
+				$arch->add_data($filename, $content->{$filename});
 			}
 			else {
 				$arch->add_files($filename);
@@ -127,8 +133,8 @@ my %actions = (
 		for my $filename (keys %{$content}) {
 			my $target = catfile($dir, $filename);
 			mkpath(dirname($target)) if not -d dirname($target);
-			if (ref $content->{$filename}) {
-				write_file($target, ${ $content->{$filename} });
+			if ($content->{$filename}) {
+				write_file($target, $content->{$filename});
 			}
 			else {
 				copy($filename, $target);
@@ -137,7 +143,8 @@ my %actions = (
 	},
 	test => sub {
 		my %opts = (@_, author => 1);
-		my $dir  = tempdir(CLEANUP => 1);
+		require File::Temp;
+		my $dir  = File::Temp::tempdir(CLEANUP => 1);
 		dispatch('distdir', %opts, dir => $dir);
 		$parser->getoptionsfromarray($opts{arguments}, \%opts, qw/release! author!/);
 		my $env = join ' ', map { $opts{$_} ? uc($_) . '_TESTING=1' : () } qw/release author automated/;
@@ -145,7 +152,8 @@ my %actions = (
 	},
 	run => sub {
 		my %opts = @_;
-		my $dir  = tempdir(CLEANUP => 1);
+		require File::Temp;
+		my $dir  = File::Temp::tempdir(CLEANUP => 1);
 		dispatch('distdir', %opts, dir => $dir);
 		my $command = @{ $opts{arguments} } ? join ' ', @{ $opts{arguments} } : $ENV{SHELL};
 		system "cd '$dir'; '$Config{perlpath}' Build.PL; ./Build; $command";
@@ -159,18 +167,19 @@ my %actions = (
 		}
 		else {
 			my $hash = $meta->effective_prereqs->as_string_hash;
+			require JSON::PP;
 			print JSON::PP->new->ascii->pretty->encode($hash);
 		}
 	},
 	regenerate => sub {
 		my %opts = @_;
-		my @files = @{ $opts{arguments} } ? @{ $opts{arguments} } : qw/Build.PL META.json META.yml MANIFEST/;
+		my %files = map { $_ => 1 } @{ $opts{arguments} } ? @{ $opts{arguments} } : qw/Build.PL META.json META.yml MANIFEST/;
 
-		my $meta = get_meta(regenerate => scalar grep { /^META\./ } @files);
-		my $content = get_files(%opts, meta => $meta, skip => \@files);
-		for my $filename (@files) {
+		my $meta = get_meta(regenerate => \%files);
+		my $content = get_files(%opts, meta => $meta, regenerate => \%files);
+		for my $filename (keys %files) {
 			mkpath(dirname($filename)) if not -d dirname($filename);
-			write_file($filename, ${ $content->{$filename} }) if ref $content->{$filename};
+			write_file($filename, $content->{$filename}) if $content->{$filename};
 		}
 	},
 );
@@ -197,11 +206,11 @@ App::ModuleBuildTiny - A standalone authoring tool for Module::Build::Tiny
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
-App::ModuleBuild contains the implementation of the L<mbtiny> tool.
+App::ModuleBuildTiny contains the implementation of the L<mbtiny> tool.
 
 =head1 FUNCTIONS
 
